@@ -14,7 +14,7 @@ function (data, period = frequency(data), start = tsp(data)[1],
             yname <- "sliced data"
         if (length(x) != nrow(y)) 
             stop("Dimensions do not match")
-        ytimes <- time(ts(rep(NA, ncol(y)), s = start, f = frequency))
+        ytimes <- time(ts(rep(NA, ncol(y)), start = start, frequency = frequency))
         if (max(abs(ytimes - floor(ytimes))) < 1e-09) 
             ylab <- paste(ytimes)
         else if (frequency == 4) 
